==> hyades.source_3.0.1.1_20041013_1609.zip: org/eclipse/hyades/logging/events/cbe/util/EventMessages_es.java <==
package org.eclipse.hyades.logging.events.cbe.util;

import java.util.ListResourceBundle;
import org.eclipse.hyades.logging.events.cbe.util.EventMessages;

/**********************************************************************
 * Copyright (c) 2004 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

/**
 * Spanish resource bundle.
 * 
 * @author Paul E. Slauenwhite
 * @version 1.0.1
 * @since 1.0.1
 */
public class EventMessages_es extends ListResourceBundle {

    /**************************************************************************
    * Implements java.util.ListResourceBundle.getContents().
    * @see java.util.ListResourceBundle#getContents
    **************************************************************************/

    public Object[][] getContents() {
        return contents_;
    }

    /**************************************************************************
    * Resource table
    **************************************************************************/
    private final static Object[][] contents_ = { { EventMessages.LOG_INVALID_JNDI_REFERENCE_EXC_, "IWAT0187E La referencia obtenida a partir del nombre JNDI especificado no es una referencia a una f\u00e1brica de sucesos.\nNombre JNDI: {0}" }, {
        EventMessages.LOG_FAILED_TO_SERIALIZE_CONTENT_HANDLER_EXC_, "IWAT0188E El manejador de contenido del suceso no se puede convertir a formato binario.\nInformaci\u00f3n adicional, si hay alguna: {0}" }, {
        EventMessages.LOG_FAILED_TO_DESERIALIZE_CONTENT_HANDLER_EXC_, "IWAT0189E El manejador de contenido del suceso al que este nombre JNDI hace referencia no se puede volver a convertir a partir de su formato binario.\nNombre JNDI: {0} \nInformaci\u00f3n adicional, si hay alguna: {1}" }, {
        EventMessages.LOG_INVALID_GLOBAL_INSTANCE_ID_EXC_, "IWAT0190E El identificador de suceso de la propiedad de Common Base Event especificada debe empezar con un car\u00e1cter alfab\u00e9tico.\nPropiedad: {0} \nIdentificador: {1} " }, {
        EventMessages.LOG_VALUE_ARRAY_SIZE_MISMATCH_EXC_, "IWAT0191E El elemento de datos ampliados especificado es de un tipo que requiere un elemento dentro de su matriz de valores, pero contiene varios valores.\nElemento de datos ampliados: {1}\nTipo: {2} \nN\u00famero de valores: {0} " }, {
        EventMessages.LOG_INVALID_TYPE_CONVERSION_EXC_, "IWAT0192E El valor del elemento de datos ampliados no se puede convertir al tipo especificado.\nElemento de datos ampliados: {2} \nValor: {0} \nTipo: {1}" }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_TYPE_EXC_, "IWAT0193E El tipo de elemento de datos ampliados no es v\u00e1lido.\nElemento de datos ampliados: {0}\nTipo: {1}" }, {
        EventMessages.LOG_EXTENDED_DATA_VALUE_NULL_EXC_, "IWAT0194E El elemento de datos ampliados contiene un valor nulo. Si el tipo es una matriz, entonces uno o m\u00e1s elementos son nulos.\nElemento de datos ampliados: {0} \nTipo: {1} " }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_BOOLEAN_EXC_, "IWAT0195E El elemento de datos ampliados contiene una serie que no es una serie booleana v\u00e1lida.\nElemento de datos ampliados: {0}\nTipo: {1} \nSerie: {2}" }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_DATE_EXC_, "IWAT0196E El elemento de datos ampliados contiene una serie dateTime que no es v\u00e1lida.\nElemento de datos ampliados: {0}\nTipo: {1}\nSerie dateTime: {2}" }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_HEX_BINARY_1_EXC_, "IWAT0197E El elemento de datos ampliados debe contener un n\u00famero par de caracteres en la propiedad hexValue.\nElemento de datos ampliados: {0} \nTipo: {1} \nValor: {2} " }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_HEX_BINARY_2_EXC_, "IWAT0198E El elemento de datos ampliados contiene un car\u00e1cter no hexadecimal en la propiedad hexValue.\nNombre del elemento de datos ampliados: {0} \nTipo: {1} \nValor: {2} \nCar\u00e1cter no hexadecimal: {3} " }, {
        EventMessages.LOG_INVALID_SITUATION_TYPE_EXC_, "IWAT0199E El valor de la propiedad especificada no es v\u00e1lido.\nPropiedad: {0} \nValor: {1} \nValores v\u00e1lidos: {2} " }, {
        EventMessages.LOG_INVALID_CREATION_TIME_EXC_, "IWAT0200E No se ha podido analizar el valor de dateTime de la propiedad especificada.\nPropiedad: {0} \nValor: {1} " }, {
        EventMessages.LOG_INVALID_LIST_ELEMENT_LENGTH_EXC_, "IWAT0201E La longitud de un elemento de la propiedad especificada supera el n\u00famero m\u00e1ximo de caracteres.\nPropiedad: {1} \nElemento: {0} \nLongitud m\u00e1xima: {2} " }, {
        EventMessages.LOG_VALUE_OUT_OF_RANGE_EXC_, "IWAT0202E El valor de la propiedad est\u00e1 fuera del rango v\u00e1lido.\nPropiedad: {1} \nValor: {0} \nRango v\u00e1lido: de {2} a {3} " }, {
        EventMessages.LOG_MISSING_REQUIRED_ATTRIBUTE_EXC_, "IWAT0203E Falta una propiedad necesaria de Common Base Event.\nPropiedad: {0} " }, {
        EventMessages.LOG_MUTUALLY_EXCLUSIVE_ATTRIBUTES_EXC_, "IWAT0204E Common Base Event contiene propiedades que se excluyen mutuamente.\nPropiedad 1: {0} \nPropiedad 2: {1} " }, {
        EventMessages.LOG_INVALID_VERSION_EXC_, "IWAT0205E La versi\u00f3n de la propiedad {0} no es v\u00e1lida. El valor debe ser 1.0.1.\nValor: {1} " }, {
        EventMessages.LOG_INVALID_GLOBAL_INSTANCE_ID_LENGTH_EXC_, "IWAT0206E La longitud del identificador de la propiedad de Common Base Event especificada est\u00e1 fuera del rango v\u00e1lido de 32 a 64 caracteres.\nPropiedad: {0} \nValor: {1} " }, {
        EventMessages.LOG_INVALID_LENGTH_EXC_, "IWAT0207E La longitud del valor de la propiedad de Common Base Event especificada supera el n\u00famero m\u00e1ximo de caracteres.\nPropiedad: {0} \nValor: {1} \nLongitud: {2} \nN\u00famero m\u00e1ximo de caracteres: {3} " }, {
        EventMessages.LOG_INVALID_LENGTH_RANGE_EXC_, "IWAT0208E La longitud del valor de la propiedad de Common Base Event especificada est\u00e1 fuera del rango v\u00e1lido.\nPropiedad: {0} \nValor: {1} \nLongitud: {2} \nRango de longitud v\u00e1lido: {3} " }, {
        EventMessages.LOG_MISSING_ATTRIBUTES_EXC_, "IWAT0209E La propiedades especificadas deben existir todas o no existir ninguna de ellas.\nPropiedades: {0} " }, {
        EventMessages.LOG_INCONSISTENT_ATTRIBUTES_EXC_, "IWAT0210E Cuando el valor de la propiedad {0} de Common Base Event es igual a {1}, la lista de propiedades especificada no debe existir.\nLista: {2} " }, {
        EventMessages.LOG_CATEGORY_MISMATCH_EXC_, "IWAT0211E El valor de la propiedad {0} no coincide con la clase de objeto a la que la propiedad situationType hace referencia.\nValor: {1} \nClase de objeto: {2}." }, {
        EventMessages.LOG_COMPONENT_IDENTIFICATION_INVALID_LOCATION_TYPE_EXC_, "IWAT0212E La identificaci\u00f3n de componente con el componente denominado [{0}] tiene un tipo de ubicaci\u00f3n que no es v\u00e1lido: [{1}]" }, {
	    EventMessages.LOG_EVENT_SAX_PARSER_UNEXPECTED_XML_ELEMENT_EXC_, "Unexpected element ''{0}'' at line {1}, column {2}." }, {
	    EventMessages.LOG_EVENT_SAX_PARSER_INCORRECT_XML_ELEMENT_EXC_ , "Expected element ''{0}'' , but found element ''{1}'' at line {2}, column {3}."}
    };
}

==> hyades.source_3.0.2_20050225_1641.zip: org/eclipse/hyades/logging/events/cbe/util/EventMessages_es.java <==
package org.eclipse.hyades.logging.events.cbe.util;

import java.util.ListResourceBundle;
import org.eclipse.hyades.logging.events.cbe.util.EventMessages;

/**********************************************************************
 * Copyright (c) 2004 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

/**
 * Spanish resource bundle.
 * 
 * @author Paul E. Slauenwhite
 * @version 1.0.1
 * @since 1.0.1
 */
public class EventMessages_es extends ListResourceBundle {

    /**************************************************************************
    * Implements java.util.ListResourceBundle.getContents().
    * @see java.util.ListResourceBundle#getContents
    **************************************************************************/

    public Object[][] getContents() {
        return contents_;
    }

    /**************************************************************************
    * Resource table
    **************************************************************************/
    private final static Object[][] contents_ = { { EventMessages.LOG_INVALID_JNDI_REFERENCE_EXC_, "IWAT0187E La referencia obtenida a partir del nombre JNDI especificado no es una referencia a una f\u00e1brica de sucesos.\nNombre JNDI: {0}" }, {
        EventMessages.LOG_FAILED_TO_SERIALIZE_CONTENT_HANDLER_EXC_, "IWAT0188E El manejador de contenido del suceso no se puede convertir a formato binario.\nInformaci\u00f3n adicional, si hay alguna: {0}" }, {
        EventMessages.LOG_FAILED_TO_DESERIALIZE_CONTENT_HANDLER_EXC_, "IWAT0189E El manejador de contenido del suceso al que este nombre JNDI hace referencia no se puede volver a convertir a partir de su formato binario.\nNombre JNDI: {0} \nInformaci\u00f3n adicional, si hay alguna: {1}" }, {
        EventMessages.LOG_INVALID_GLOBAL_INSTANCE_ID_EXC_, "IWAT0190E El identificador de suceso de la propiedad de Common Base Event especificada debe empezar con un car\u00e1cter alfab\u00e9tico.\nPropiedad: {0} \nIdentificador: {1} " }, {
        EventMessages.LOG_VALUE_ARRAY_SIZE_MISMATCH_EXC_, "IWAT0191E El elemento de datos ampliados especificado es de un tipo que requiere un elemento dentro de su matriz de valores, pero contiene varios valores.\nElemento de datos ampliados: {1}\nTipo: {2} \nN\u00famero de valores: {0} " }, {
        EventMessages.LOG_INVALID_TYPE_CONVERSION_EXC_, "IWAT0192E El valor del elemento de datos ampliados no se puede convertir al tipo especificado.\nElemento de datos ampliados: {2} \nValor: {0} \nTipo: {1}" }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_TYPE_EXC_, "IWAT0193E El tipo de elemento de datos ampliados no es v\u00e1lido.\nElemento de datos ampliados: {0}\nTipo: {1}" }, {
        EventMessages.LOG_EXTENDED_DATA_VALUE_NULL_EXC_, "IWAT0194E El elemento de datos ampliados contiene un valor nulo. Si el tipo es una matriz, entonces uno o m\u00e1s elementos son nulos.\nElemento de datos ampliados: {0} \nTipo: {1} " }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_BOOLEAN_EXC_, "IWAT0195E El elemento de datos ampliados contiene una serie que no es una serie booleana v\u00e1lida.\nElemento de datos ampliados: {0}\nTipo: {1} \nSerie: {2}" }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_DATE_EXC_, "IWAT0196E El elemento de datos ampliados contiene una serie dateTime que no es v\u00e1lida.\nElemento de datos ampliados: {0}\nTipo: {1}\nSerie dateTime: {2}" }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_HEX_BINARY_1_EXC_, "IWAT0197E El elemento de datos ampliados debe contener un n\u00famero par de caracteres en la propiedad hexValue.\nElemento de datos ampliados: {0} \nTipo: {1} \nValor: {2} " }, {
        EventMessages.LOG_EXTENDED_DATA_INVALID_HEX_BINARY_2_EXC_, "IWAT0198E El elemento de datos ampliados contiene un car\u00e1cter no hexadecimal en la propiedad hexValue.\nNombre del elemento de datos ampliados: {0} \nTipo: {1} \nValor: {2} \nCar\u00e1cter no hexadecimal: {3} " }, {
        EventMessages.LOG_INVALID_SITUATION_TYPE_EXC_, "IWAT0199E El valor de la propiedad especificada no es v\u00e1lido.\nPropiedad: {0} \nValor: {1} \nValores v\u00e1lidos: {2} " }, {
        EventMessages.LOG_INVALID_CREATION_TIME_EXC_, "IWAT0200E No se ha podido analizar el valor de dateTime de la propiedad especificada.\nPropiedad: {0} \nValor: {1} " }, {
        EventMessages.LOG_INVALID_LIST_ELEMENT_LENGTH_EXC_, "IWAT0201E La longitud de un elemento de la propiedad especificada supera el n\u00famero m\u00e1ximo de caracteres.\nPropiedad: {1} \nElemento: {0} \nLongitud m\u00e1xima: {2} " }, {
        EventMessages.LOG_VALUE_OUT_OF_RANGE_EXC_, "IWAT0202E El valor de la propiedad est\u00e1 fuera del rango v\u00e1lido.\nPropiedad: {1} \nValor: {0} \nRango v\u00e1lido: de {2} a {3} " }, {
        EventMessages.LOG_MISSING_REQUIRED_ATTRIBUTE_EXC_, "IWAT0203E Falta una propiedad necesaria de Common Base Event.\nPropiedad: {0} " }, {
        EventMessages.LOG_MUTUALLY_EXCLUSIVE_ATTRIBUTES_EXC_, "IWAT0204E Common Base Event contiene propiedades que se excluyen mutuamente.\nPropiedad 1: {0} \nPropiedad 2: {1} " }, {
        EventMessages.LOG_INVALID_VERSION_EXC_, "IWAT0205E La versi\u00f3n de la propiedad {0} no es v\u00e1lida. El valor debe ser 1.0.1.\nValor: {1} " }, {
        EventMessages.LOG_INVALID_GLOBAL_INSTANCE_ID_LENGTH_EXC_, "IWAT0206E La longitud del identificador de la propiedad de Common Base Event especificada est\u00e1 fuera del rango v\u00e1lido de 32 a 64 caracteres.\nPropiedad: {0} \nValor: {1} " }, {
        EventMessages.LOG_INVALID_LENGTH_EXC_, "IWAT0207E La longitud del valor de la propiedad de Common Base Event especificada supera el n\u00famero m\u00e1ximo de caracteres.\nPropiedad: {0} \nValor: {1} \nLongitud: {2} \nN\u00famero m\u00e1ximo de caracteres: {3} " }, {
        EventMessages.LOG_INVALID_LENGTH_RANGE_EXC_, "IWAT0208E La longitud del valor de la propiedad de Common Base Event especificada est\u00e1 fuera del rango v\u00e1lido.\nPropiedad: {0} \nValor: {1} \nLongitud: {2} \nRango de longitud v\u00e1lido: {3} " }, {
        EventMessages.LOG_MISSING_ATTRIBUTES_EXC_, "IWAT0209E La propiedades especificadas deben existir todas o no existir ninguna de ellas.\nPropiedades: {0} " }, {
        EventMessages.LOG_INCONSISTENT_ATTRIBUTES_EXC_, "IWAT0210E Cuando el valor de la propiedad {0} de Common Base Event es igual a {1}, la lista de propiedades especificada no debe existir.\nLista: {2} " }, {
        EventMessages.LOG_CATEGORY_MISMATCH_EXC_, "IWAT0211E El valor de la propiedad {0} no coincide con la clase de objeto a la que la propiedad situationType hace referencia.\nValor: {1} \nClase de objeto: {2}." }, {
        EventMessages.LOG_COMPONENT_IDENTIFICATION_INVALID_LOCATION_TYPE_EXC_, "IWAT0212E La identificaci\u00f3n de componente con el componente denominado [{0}] tiene un tipo de ubicaci\u00f3n que no es v\u00e1lido: [{1}]" }, {
	    EventMessages.LOG_EVENT_SAX_PARSER_UNEXPECTED_XML_ELEMENT_EXC_, "Unexpected element ''{0}'' at line {1}, column {2}." }, {
		EventMessages.LOG_EVENT_SAX_PARSER_INCORRECT_XML_ELEMENT_EXC_ , "Expected element ''{0}'' , but found element ''{1}'' at line {2}, column {3}."}, {
		EventMessages.LOG_EVENT_SAX_PARSER_INVALID_XML_ATTRIBUTE_EXC_ , "IWAT0157E The ''{0}'' attribute contains the invalid value ''{1}'' at line {2}, column {3}."}
    };
}
